import { LuciaAdapter } from "./abstract.js";
import type { IdTokenClaims, TokenSet, UserinfoResponse } from "openid-client";
import { type BetterSQLite3Database } from "drizzle-orm/better-sqlite3";
import type { Session, UserId } from "lucia";
import type { MaybePromise } from "@sveltejs/kit";
import type { Empty } from "../types.js";
declare const userTable: import("drizzle-orm/sqlite-core/table.js").SQLiteTableWithColumns<{
    name: "user";
    schema: undefined;
    columns: {
        id: import("drizzle-orm/sqlite-core/index.js").SQLiteColumn<{
            name: "id";
            tableName: "user";
            dataType: "string";
            columnType: "SQLiteText";
            data: string;
            driverParam: string;
            notNull: true;
            hasDefault: false;
            isPrimaryKey: true;
            isAutoincrement: false;
            hasRuntimeDefault: false;
            enumValues: [string, ...string[]];
            baseColumn: never;
            generated: undefined;
        }, object>;
        subject: import("drizzle-orm/sqlite-core/index.js").SQLiteColumn<{
            name: "subject";
            tableName: "user";
            dataType: "string";
            columnType: "SQLiteText";
            data: string;
            driverParam: string;
            notNull: true;
            hasDefault: false;
            isPrimaryKey: false;
            isAutoincrement: false;
            hasRuntimeDefault: false;
            enumValues: [string, ...string[]];
            baseColumn: never;
            generated: undefined;
        }, object>;
        claims: import("drizzle-orm/sqlite-core/index.js").SQLiteColumn<{
            name: "claims";
            tableName: "user";
            dataType: "string";
            columnType: "SQLiteText";
            data: string;
            driverParam: string;
            notNull: true;
            hasDefault: false;
            isPrimaryKey: false;
            isAutoincrement: false;
            hasRuntimeDefault: false;
            enumValues: [string, ...string[]];
            baseColumn: never;
            generated: undefined;
        }, object>;
    };
    dialect: "sqlite";
}>;
declare const sessionTable: import("drizzle-orm/sqlite-core/table.js").SQLiteTableWithColumns<{
    name: "session";
    schema: undefined;
    columns: {
        id: import("drizzle-orm/sqlite-core/index.js").SQLiteColumn<{
            name: "id";
            tableName: "session";
            dataType: "string";
            columnType: "SQLiteText";
            data: string;
            driverParam: string;
            notNull: true;
            hasDefault: false;
            isPrimaryKey: true;
            isAutoincrement: false;
            hasRuntimeDefault: false;
            enumValues: [string, ...string[]];
            baseColumn: never;
            generated: undefined;
        }, object>;
        userId: import("drizzle-orm/sqlite-core/index.js").SQLiteColumn<{
            name: "user_id";
            tableName: "session";
            dataType: "string";
            columnType: "SQLiteText";
            data: string;
            driverParam: string;
            notNull: true;
            hasDefault: false;
            isPrimaryKey: false;
            isAutoincrement: false;
            hasRuntimeDefault: false;
            enumValues: [string, ...string[]];
            baseColumn: never;
            generated: undefined;
        }, object>;
        expiresAt: import("drizzle-orm/sqlite-core/index.js").SQLiteColumn<{
            name: "expires_at";
            tableName: "session";
            dataType: "number";
            columnType: "SQLiteInteger";
            data: number;
            driverParam: number;
            notNull: true;
            hasDefault: false;
            isPrimaryKey: false;
            isAutoincrement: false;
            hasRuntimeDefault: false;
            enumValues: undefined;
            baseColumn: never;
            generated: undefined;
        }, object>;
        idToken: import("drizzle-orm/sqlite-core/index.js").SQLiteColumn<{
            name: "id_token";
            tableName: "session";
            dataType: "string";
            columnType: "SQLiteText";
            data: string;
            driverParam: string;
            notNull: true;
            hasDefault: false;
            isPrimaryKey: false;
            isAutoincrement: false;
            hasRuntimeDefault: false;
            enumValues: [string, ...string[]];
            baseColumn: never;
            generated: undefined;
        }, object>;
    };
    dialect: "sqlite";
}>;
declare class SqliteDrizzleAdapter extends LuciaAdapter<Empty, User> {
    db: BetterSQLite3Database;
    constructor();
    initDatabase(): void;
    getUserId(subject: string): Promise<string | undefined>;
    newUser(subject: string, userId: string, claims: IdTokenClaims): Promise<string>;
    newSession(userId: UserId, tokenSet: TokenSet & {
        id_token: string;
    }): Promise<Session>;
    getIdToken(session: Session): MaybePromise<string | undefined>;
}
export declare const adapter: SqliteDrizzleAdapter;
interface User {
    subject: string;
    claims: UserinfoResponse;
}
interface ISession {
    idToken: string;
}
declare module "@arise/aidc-sveltekit" {
    interface Types {
        User: User;
        Session: ISession;
        DatabaseUserAttributes: typeof userTable.$inferSelect;
        DatabaseSessionAttributes: typeof sessionTable.$inferSelect;
    }
}
export {};
